@@ -11,6 +11,7 @@ import random
 import base64
 import html as html_decode
 from colorama import Fore
+from tqdm import tqdm as td
 
 import xlrd
 import xlwt
@@ -516,4 +517,6 @@ def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True):
             color = eval(color)
     else:
         color = Fore.LIGHTYELLOW_EX
-    print(color + self, *args, sep=sep, end=end, file=file)
+    print(color + str(self), *args, sep=sep, end=end, file=file)
+
+tqdm = td
